@@ -48,8 +48,9 @@ from certbot.interfaces import AccountStorage
 logger = logging.getLogger(__name__)
 
 
-def acme_from_config_key(config: configuration.NamespaceConfig, key: jose.JWK,
-                         regr: Optional[messages.RegistrationResource] = None
+def acme_from_config_key(config: configuration.NamespaceConfig,
+                         key: jose.JWK,
+                         regr: Optional[messages.RegistrationResource] = None,
                          ) -> acme_client.ClientV2:
     """Wrangle ACME client construction"""
     if key.typ == 'EC':
@@ -186,15 +187,9 @@ def register(config: configuration.NamespaceConfig, account_storage: AccountStor
     # Log non-standard actions, potentially wrong API calls
     if account_storage.find_all():
         logger.info("There are already existing accounts for %s", config.server)
-    if config.email is None:
-        if not config.register_unsafely_without_email:
-            msg = ("No email was provided and "
-                   "--register-unsafely-without-email was not present.")
-            logger.error(msg)
-            raise errors.Error(msg)
-        if not config.dry_run:
-            logger.debug("Registering without email!")
 
+    if config.email == "":
+        config.email = None
     # If --dry-run is used, and there is no staging account, create one with no email.
     if config.dry_run:
         config.email = None
